@@ -132,6 +132,7 @@ class API:
         self.create_function_threads = []
         self.update_function = update_function
         self.communicateLock = threading.Lock()
+        self.track_hook: Callable[[Message], None] = None
 
     def __send(self, msg: str) -> None:
         """Sends a socket message
@@ -424,3 +425,10 @@ class API:
         self.__send({"Command": "Skip Currently Playing", "Value":None})
         tmp = self.__wait_for_response()
         return tmp
+
+    def set_as_hook_for_track_finished(self, callable: Callable[[Message], None]) -> bool:
+        self.track_hook = callable
+        self.__send({"Command": "Set As Track Finished", "Value": None})
+        tmp = self.__wait_for_response()
+        if not tmp: self.track_hook = None
+        return tmp
\ No newline at end of file
